@@ -89,7 +89,7 @@ def run(url: str, interval=10, wait=5):
 def main():
     print("[1] Run driver with official API")
     print("[2] Test driver with local API")
-    print("[3] Test driver with local API")
+    print("[3] Test driver with cloud API")
     print("[4] presentation")
     response = input("What would you like to run? ")
     choices = ['1', '2', '3', '4']
